[![CircleCI](https://circleci.com/gh/portant-shop/django-wspay/tree/master.svg?style=svg)](https://circleci.com/gh/portant-shop/django-wspay/tree/master)

# django-wspay
Django app to use wspay payment gateway
